@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 
+# Notification Center code borrowed from https://github.com/maranas/pyNotificationCenter/blob/master/pyNotificationCenter.py
+
 import os, sys, json, re, hashlib, argparse
 
 try:
@@ -8,6 +10,32 @@ except ImportError:
     print "Please install boto. `pip install boto`"
     sys.exit(os.EX_UNAVAILABLE)
     
+try:
+    import Foundation, objc
+    notifications   =   True
+except ImportError:
+    notifications   =   False
+    
+if notifications:
+    try:
+        NSUserNotification          =   objc.lookUpClass('NSUserNotification')
+        NSUserNotificationCenter    =   objc.lookUpClass('NSUserNotificationCenter')
+    except objc.nosuchclass_error:
+        notifications   =   False
+        
+def notify(env, text):
+    if __name__ == "__main__":
+        print text
+    if notifications:
+        notification    =   NSUserNotification.alloc().init()
+        notification.setTitle_('d3ploy')
+        notification.setSubtitle_(env)
+        notification.setInformativeText_(text)
+        notification.setUserInfo_({})
+        notification.setSoundName_("NSUserNotificationDefaultSoundName")
+        notification.setDeliveryDate_(Foundation.NSDate.dateWithTimeInterval_sinceDate_(0, Foundation.NSDate.date()))
+        NSUserNotificationCenter.defaultUserNotificationCenter().scheduleNotification_(notification)
+    
 valid_acls      =   ["private", "public-read", "public-read-write", "authenticated-read"]
 
 parser          =   argparse.ArgumentParser()
@@ -38,11 +66,13 @@ if AWS_SECRET is None:
     AWS_SECRET  =   os.environ.get('AWS_SECRET_ACCESS_KEY')
     
 def upload_files(env, config):
-    print 'Using settings for "%s" environment' % env
+    if __name__ == "__main__":
+        print 'Using settings for "%s" environment' % env
     
     bucket              =   config.get('bucket')
     if not bucket:
-        print 'A bucket to upload to was not specified for "%s" environment' % args.environment
+        if __name__ == "__main__":
+            print 'A bucket to upload to was not specified for "%s" environment' % args.environment
         sys.exit(os.EX_NOINPUT)
 
     KEY         =   config.get('aws_key', AWS_KEY)
@@ -50,7 +80,8 @@ def upload_files(env, config):
     SECRET      =   config.get('aws_secret', AWS_SECRET)
     
     if KEY is None or SECRET is None:
-        print "AWS credentials were not found. See https://gist.github.com/dryan/5317321 for more information."
+        if __name__ == "__main__":
+            print "AWS credentials were not found. See https://gist.github.com/dryan/5317321 for more information."
         sys.exit(os.EX_NOINPUT)
     
     s3connection        =   boto.connect_s3(KEY, SECRET)
@@ -59,7 +90,8 @@ def upload_files(env, config):
     try:
         s3bucket        =   s3connection.get_bucket(bucket)
     except boto.exception.S3ResponseError:
-        print 'Bucket "%s" could not be retrieved with the specified credentials' % bucket
+        if __name__ == "__main__":
+            print 'Bucket "%s" could not be retrieved with the specified credentials' % bucket
         sys.exit(os.EX_NOINPUT)
 
     # get the rest of the options
@@ -106,7 +138,8 @@ def upload_files(env, config):
                 break
             md5.update(data)
         if s3key is None or args.force or not s3key.etag.strip('"') == md5.hexdigest():
-            print 'Copying %s to %s%s' % (filename, bucket, keyname)
+            if __name__ == "__main__":
+                print 'Copying %s to %s%s' % (filename, bucket, keyname)
             updated     +=  1
             if args.dry_run:
                 continue
@@ -117,33 +150,38 @@ def upload_files(env, config):
         
     for key in s3bucket.list(prefix = bucket_path.lstrip('/')):
         if not key.name in keynames:
-            print 'Deleting %s/%s' % (bucket, key.name.lstrip('/'))
+            if __name__ == "__main__":
+                print 'Deleting %s/%s' % (bucket, key.name.lstrip('/'))
             deleted     +=  1
             if args.dry_run:
                 continue
             key.delete()
         
     verb    =   "would be" if args.dry_run else "were"
-    print "%d files %s updated and %d files %s removed" % (updated, verb, deleted, verb)
-    print ""
+    notify(args.environment, "%d files %s updated and %d files %s removed" % (updated, verb, deleted, verb))
+    if __name__ == "__main__":
+        print ""
 
 # load the config file for this folder
 try:
     config          =   open('deploy.json', 'r')
 except IOError:
-    print "deploy.json file is missing. See https://gist.github.com/dryan/5317321 for more information."
+    if __name__ == "__main__":
+        print "deploy.json file is missing. See https://gist.github.com/dryan/5317321 for more information."
     sys.exit(os.EX_NOINPUT)
 
 config              =   json.load(config)
 
 if not args.environment in config:
-    print 'The "%s" environment was not found in deploy.json' % args.environment
+    if __name__ == "__main__":
+        print 'The "%s" environment was not found in deploy.json' % args.environment
     sys.exit(os.EX_NOINPUT)
 
 def main():
     if args.all:
         for environ in config:
-            print "Uploading environment %d of %d" % (config.keys().index(environ) + 1, len(config.keys()))
+            if __name__ == "__main__":
+                print "Uploading environment %d of %d" % (config.keys().index(environ) + 1, len(config.keys()))
             upload_files(environ, config[environ])
     else:
         upload_files(args.environment, config[args.environment])
